@@ -1,3 +1,4 @@
+import gzip
 import logging
 import click
 from os import environ, path
@@ -110,8 +111,6 @@ def build_image(**kwargs):
         common.push_image(config, config['instance_image'], config['image_git_tag'])
         common.notify_orchest(config, is_latest=is_latest)
         common.save_imagename(config["ci_commit_ref_slug"], config)
-        # TODO: Old compatibility, remove this line after all repo are migrated
-        common.save_imagename(config["ci_commit_ref_name"], config)
     common.clear_images(config)
     sys.exit(0)
 
@@ -124,7 +123,7 @@ def check_log(logpath):
     """Checks odoo log in image to analize if there are warnings
     and show them."""
     _logger.info('Check log command')
-    logpaths = glob(path.join(logpath, "odoo.log_*"))
+    logpaths = glob(path.join(logpath, "odoo.log.gz_*"))
 
     if not logpaths:
         _logger.warning('Odoo log file was not found in path: %s', logpath)
@@ -133,7 +132,7 @@ def check_log(logpath):
     has_warnings = False
     for logpath in logpaths:
         _logger.info("Odoo log path: %s", logpath)
-        with open(logpath) as flog:
+        with gzip.open(logpath, "rb") as flog:
             sucesss, log = resume_log(flog)
 
         all_warnings = log.get('warnings')
