@@ -421,6 +421,7 @@ def start_instance(config):
         "DB_PASSWORD": "odoo",
         "DB_HOST": config['postgres_container'],
         "ODOO_CONFIG_FILE": "/home/odoo/.openerp_serverrc",
+        "AUTOSTART": "false",
         # Enable this to debug coverage
         # "COVERAGE_DEBUG": "config,dataio,process",
     }
@@ -767,13 +768,18 @@ def resume_log(log_lines, allow_deprecated=False):
     # Read log file removing ASCII color escapes:
     # http://serverfault.com/questions/71285
     color_regex = re.compile(r'\x1B\[([0-9]{1,2}(;[0-9]{1,2})?)?[m|K]')
-    is_magic_line = False
+    is_module_loaded = False
+    is_build_ended = False
     for line in log_lines:
         if isinstance(line, bytes):
             line = line.decode("UTF-8")
         original_line = line.strip()
-        if 'odoo.modules.loading: Modules loaded.' in original_line:
-            is_magic_line = True
+        if ".modules.loading: Modules loaded." in original_line:
+            is_module_loaded = True
+        elif "Initiating shutdown" in original_line:
+            # Using the same way than runbot:
+            # https://github.com/odoo/runbot/blob/964a88cb/runbot/models/build_config.py#L998
+            is_build_ended = True
         # Remove colorized when exists to regex
         stripped_line = color_regex.sub('', original_line)
         for name, criteria in filters.items():
@@ -784,7 +790,13 @@ def resume_log(log_lines, allow_deprecated=False):
                     success = False
                 res.get(name).append(original_line)
                 break
-    return success and is_magic_line, res
+    if not success:
+        _logger.error("Error or traceback found in logs")
+    elif not is_module_loaded:
+        _logger.error("Modules loaded not found in logs")
+    elif not is_build_ended:
+        _logger.error('No "Initiating shutdown" found in logs, maybe because of cpu limit or Aborted (core dumped).')
+    return success and is_module_loaded and is_build_ended, res
 
 
 def run_image_tests(config, test_only=False):
